# Signal K Data Model Reference

This document is meant as the human-oriented reference to accompany the actual JSON Schema specification and is produced from the schema files. Any changes to the reference material below should be made to the original schema files.

Signal K uses [SI units](https://en.wikipedia.org/wiki/International_System_of_Units) almost everywhere, with the exception of geographic coordinates. The following units are in use:
- A : Ampere
- C : Coulomb
- Hz : Hertz
- ISO-8601 (UTC) : ISO-8601 string representation of time in Universal Time Coordinated
- J : Joule
- K : Kelvin
- Pa : Pascal
- V : Volt
- W : Watt
- deg : Degree
- kg : Kilogram
- m : Meter
- m/s : Meters per second
- m2 : Square meter
- m3 : Cubic meter
- m3/s : Cubic meter per second
- rad : Radian
- rad/s : Radian per second
- ratio : Ratio
- s : Second

## Keys
#### /self

**Description:** This holds the key (UUID, MMSI or URL) of this vessel, the actual data is in the vessels array.

---

#### /vessels

**Description:** A wrapper object for vessel objects, each describing vessels in range, including this vessel.

---

#### /vessels/&lt;RegExp&gt;

**Title:** vessel

**Description:** This regex pattern is used for validation of an MMSI or Signal K UUID identifier for the vessel. Examples: urn:mrn:imo:mmsi:230099999 urn:mrn:signalk:uuid:c0d79334-4e25-4245-8892-54e8ccc8021d

---

#### /vessels/&lt;RegExp&gt;/url

**Description:** URL based identity of the vessel, if available.

---

#### /vessels/&lt;RegExp&gt;/mmsi

**Description:** MMSI number of the vessel, if available.

---

#### /vessels/&lt;RegExp&gt;/uuid

**Description:** A unique Signal K flavoured maritime resource identifier, assigned by the server.

---

#### /vessels/&lt;RegExp&gt;/name

**Description:** The common name of the vessel

---

#### /vessels/&lt;RegExp&gt;/flag

**Description:** The country of ship registration, or flag state of the vessel

---

#### /vessels/&lt;RegExp&gt;/port

**Description:** The home port of the vessel

---

#### /vessels/&lt;RegExp&gt;/registrations

**Description:** The various registrations of the vessel.

---

#### /vessels/&lt;RegExp&gt;/registrations/imo

**Description:** The IMO number of the vessel.

---

#### /vessels/&lt;RegExp&gt;/registrations/national

**Description:** The national registration number of the vessel.

---

#### /vessels/&lt;RegExp&gt;/registrations/national/&lt;RegExp&gt;

**Description:** This regex pattern is used for validating the identifier for the registration

---

#### /vessels/&lt;RegExp&gt;/registrations/national/&lt;RegExp&gt;/country

**Description:** The ISO 3166-2 country code.

---

#### /vessels/&lt;RegExp&gt;/registrations/national/&lt;RegExp&gt;/registration

**Description:** The registration code

---

#### /vessels/&lt;RegExp&gt;/registrations/national/&lt;RegExp&gt;/description

**Description:** The registration description

---

#### /vessels/&lt;RegExp&gt;/registrations/local

**Description:** A local or state registration number of the vessel.

---

#### /vessels/&lt;RegExp&gt;/registrations/local/&lt;RegExp&gt;

**Description:** This regex pattern is used for validating the identifier for the registration

---

#### /vessels/&lt;RegExp&gt;/registrations/local/&lt;RegExp&gt;/registration

**Description:** The registration code

---

#### /vessels/&lt;RegExp&gt;/registrations/local/&lt;RegExp&gt;/description

**Description:** The registration description

---

#### /vessels/&lt;RegExp&gt;/registrations/other

**Description:** Other registration or permits for the vessel.

---

#### /vessels/&lt;RegExp&gt;/registrations/other/&lt;RegExp&gt;

**Description:** This regex pattern is used for validating the identifier for the registration

---

#### /vessels/&lt;RegExp&gt;/registrations/other/&lt;RegExp&gt;/registration

**Description:** The registration code

---

#### /vessels/&lt;RegExp&gt;/registrations/other/&lt;RegExp&gt;/description

**Description:** The registration description

---

#### /vessels/&lt;RegExp&gt;/communication

**Title:** communication

**Description:** Communication data including Radio, Telephone, E-Mail, etc.

---

#### /vessels/&lt;RegExp&gt;/communication/callsignVhf

**Description:** Callsign for VHF communication

---

#### /vessels/&lt;RegExp&gt;/communication/callsignHf

**Description:** Callsign for HF communication

---

#### /vessels/&lt;RegExp&gt;/communication/phoneNumber

**Description:** Phone number of skipper

---

#### /vessels/&lt;RegExp&gt;/communication/emailHf

**Description:** Email address to be used for HF email (Winmail, Airmail, Sailmail)

---

#### /vessels/&lt;RegExp&gt;/communication/email

**Description:** Regular email for the skipper

---

#### /vessels/&lt;RegExp&gt;/communication/satPhoneNumber

**Description:** Satellite phone number for vessel.

---

#### /vessels/&lt;RegExp&gt;/communication/skipperName

**Description:** Full name of the skipper of the vessel.

---

#### /vessels/&lt;RegExp&gt;/communication/crewNames

**Description:** Array with the names of the crew

---

#### /vessels/&lt;RegExp&gt;/environment

**Title:** environment

**Description:** Environmental data measured locally including Depth, Wind, Temp, etc.

---

#### /vessels/&lt;RegExp&gt;/environment/outside

**Description:** Environmental conditions outside of the vessel's hull

---

#### /vessels/&lt;RegExp&gt;/environment/outside/temperature

**Units:** K (Kelvin)

**Description:** Current outside air temperature

---

#### /vessels/&lt;RegExp&gt;/environment/outside/dewPointTemperature

**Units:** K (Kelvin)

**Description:** Current outside dew point temperature

---

#### /vessels/&lt;RegExp&gt;/environment/outside/apparentWindChillTemperature

**Units:** K (Kelvin)

**Description:** Current outside apparent wind chill temperature

---

#### /vessels/&lt;RegExp&gt;/environment/outside/theoreticalWindChillTemperature

**Units:** K (Kelvin)

**Description:** Current outside theoretical wind chill temperature

---

#### /vessels/&lt;RegExp&gt;/environment/outside/heatIndexTemperature

**Units:** K (Kelvin)

**Description:** Current outside heat index temperature

---

#### /vessels/&lt;RegExp&gt;/environment/outside/pressure

**Units:** Pa (Pascal)

**Description:** Current outside air ambient pressure

---

#### /vessels/&lt;RegExp&gt;/environment/outside/humidity

**Units:** ratio (Ratio)

**Description:** Current outside air relative humidity

---

#### /vessels/&lt;RegExp&gt;/environment/outside/illuminance

**Units:** Lux (undefined)

**Description:** Current outside ambient light flux.

---

#### /vessels/&lt;RegExp&gt;/environment/inside

**Description:** Environmental conditions inside the vessel's hull

---

#### /vessels/&lt;RegExp&gt;/environment/inside/temperature

**Units:** K (Kelvin)

**Description:** Current inside air temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/humidity

**Units:** ratio (Ratio)

**Description:** Current inside air relative humidity

---

#### /vessels/&lt;RegExp&gt;/environment/inside/engineRoom

**Description:** Current engine room air temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/engineRoom/temperature

**Units:** K (Kelvin)

**Description:** Temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/mainCabin

**Description:** Current main cabin air temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/mainCabin/temperature

**Units:** K (Kelvin)

**Description:** Temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/refrigerator

**Description:** Current refrigerator temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/refrigerator/temperature

**Units:** K (Kelvin)

**Description:** Temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/freezer

**Description:** Current freezer temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/freezer/temperature

**Units:** K (Kelvin)

**Description:** Temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/heating

**Description:** Current heating temperature

---

#### /vessels/&lt;RegExp&gt;/environment/inside/heating/temperature

**Units:** K (Kelvin)

**Description:** Temperature

---

#### /vessels/&lt;RegExp&gt;/environment/water

**Description:** Environmental conditions of the water that the vessel is sailing in

---

#### /vessels/&lt;RegExp&gt;/environment/water/temperature

**Units:** K (Kelvin)

**Description:** Current water temperature

---

#### /vessels/&lt;RegExp&gt;/environment/water/salinity

**Units:** ratio (Ratio)

**Description:** Water salinity

---

#### /vessels/&lt;RegExp&gt;/environment/water/liveWell

**Description:** Current livewell temperature

---

#### /vessels/&lt;RegExp&gt;/environment/water/liveWell/temperature

**Units:** K (Kelvin)

**Description:** Temperature

---

#### /vessels/&lt;RegExp&gt;/environment/water/baitWell

**Description:** Current baitwell air temperature

---

#### /vessels/&lt;RegExp&gt;/environment/water/baitWell/temperature

**Units:** K (Kelvin)

**Description:** Temperature

---

#### /vessels/&lt;RegExp&gt;/environment/depth

**Title:** depth

**Description:** Depth related data

---

#### /vessels/&lt;RegExp&gt;/environment/depth/belowKeel

**Units:** m (Meter)

**Description:** Depth below keel

---

#### /vessels/&lt;RegExp&gt;/environment/depth/belowTransducer

**Units:** m (Meter)

**Description:** Depth below Transducer

---

#### /vessels/&lt;RegExp&gt;/environment/depth/belowSurface

**Units:** m (Meter)

**Description:** Depth from surface

---

#### /vessels/&lt;RegExp&gt;/environment/depth/transducerToKeel

**Units:** m (Meter)

**Description:** Depth from the transducer to the bottom of the keel

---

#### /vessels/&lt;RegExp&gt;/environment/depth/surfaceToTransducer

**Units:** m (Meter)

**Description:** Depth transducer is below the water surface

---

#### /vessels/&lt;RegExp&gt;/environment/current

**Title:** current

**Description:** Direction and strength of current affecting the vessel

**Fields:**

* drift (The speed component of the water current vector), units: m/s (Meters per second)
* setTrue (The direction component of the water current vector referenced to true (geographic) north), units: rad (Radian)
* setMagnetic (The direction component of the water current vector referenced to magnetic north), units: rad (Radian)

---

#### /vessels/&lt;RegExp&gt;/environment/tide

**Title:** tide

**Description:** Tide data

---

#### /vessels/&lt;RegExp&gt;/environment/tide/heightHigh

**Units:** m (Meter)

**Description:** Next high tide height  relative to lowest astronomical tide (LAT/Chart Datum)

---

#### /vessels/&lt;RegExp&gt;/environment/tide/heightNow

**Units:** m (Meter)

**Description:** The current tide height  relative to lowest astronomical tide (LAT/Chart Datum)

---

#### /vessels/&lt;RegExp&gt;/environment/tide/heightLow

**Units:** m (Meter)

**Description:** The next low tide height relative to lowest astronomical tide (LAT/Chart Datum)

---

#### /vessels/&lt;RegExp&gt;/environment/tide/timeLow

**Units:** RFC 3339 (UTC) (undefined)

**Description:** Time of the next low tide in UTC

---

#### /vessels/&lt;RegExp&gt;/environment/tide/timeHigh

**Units:** RFC 3339 (UTC) (undefined)

**Description:** Time of next high tide in UTC

---

#### /vessels/&lt;RegExp&gt;/environment/heave

**Units:** m (Meter)

**Description:** Vertical movement of the vessel due to waves

---

#### /vessels/&lt;RegExp&gt;/environment/wind

**Title:** wind

**Description:** Wind data.

---

#### /vessels/&lt;RegExp&gt;/environment/wind/angleApparent

**Units:** rad (Radian)

**Description:** Apparent wind angle, negative to port

---

#### /vessels/&lt;RegExp&gt;/environment/wind/angleTrueGround

**Units:** rad (Radian)

**Description:** True wind angle based on speed over ground, negative to port

---

#### /vessels/&lt;RegExp&gt;/environment/wind/angleTrueWater

**Units:** rad (Radian)

**Description:** True wind angle based on speed through water, negative to port

---

#### /vessels/&lt;RegExp&gt;/environment/wind/directionChangeAlarm

**Units:** rad (Radian)

**Description:** The angle the wind needs to shift to raise an alarm

---

#### /vessels/&lt;RegExp&gt;/environment/wind/directionTrue

**Units:** rad (Radian)

**Description:** The wind direction relative to true north

---

#### /vessels/&lt;RegExp&gt;/environment/wind/directionMagnetic

**Units:** rad (Radian)

**Description:** The wind direction relative to magnetic north

---

#### /vessels/&lt;RegExp&gt;/environment/wind/speedTrue

**Units:** m/s (Meters per second)

**Description:** Wind speed over water (as calculated from speedApparent and vessel's speed through water)

---

#### /vessels/&lt;RegExp&gt;/environment/wind/speedOverGround

**Units:** m/s (Meters per second)

**Description:** Wind speed over ground (as calculated from speedApparent and vessel's speed over ground)

---

#### /vessels/&lt;RegExp&gt;/environment/wind/speedApparent

**Units:** m/s (Meters per second)

**Description:** Apparent wind speed

---

#### /vessels/&lt;RegExp&gt;/environment/time

**Description:** A time reference for the vessel. All clocks on the vessel dispaying local time should use the timezone offset here. If a timezoneRegion is supplied the timezone must also be supplied. If timezoneRegion is supplied that should be displayed by UIs in preference to simply timezone. ie 12:05 (Europe/London) should be displayed in preference to 12:05 (UTC+01:00)

**Fields:**

* millis (Milliseconds since the UNIX epoch (1970-01-01 00:00:00))
* timezoneOffset (Onboard timezone offset from UTC in hours and minutes (-)hhmm. +ve means east of Greenwich. For use by UIs)
* timezoneRegion (Onboard timezone offset as listed in the IANA timezone database (tz database))

---

#### /vessels/&lt;RegExp&gt;/environment/mode

**Description:** Mode of the vessel based on the current conditions. Can be combined with navigation.state to control vessel signals eg switch to night mode for instrumentation and lights, or make sound signals for fog.

---

#### /vessels/&lt;RegExp&gt;/navigation

**Title:** navigation

**Description:** Navigation data including Position, Course to next WP information, etc.

---

#### /vessels/&lt;RegExp&gt;/navigation/lights

**Title:** Navigation lights

**Description:** Current state of the vessels navigation lights

---

#### /vessels/&lt;RegExp&gt;/navigation/courseOverGroundMagnetic

**Units:** rad (Radian)

**Description:** Course over ground (magnetic)

---

#### /vessels/&lt;RegExp&gt;/navigation/courseOverGroundTrue

**Units:** rad (Radian)

**Description:** Course over ground (true)

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline

**Title:** Course

**Description:** Course information computed with Rhumbline

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/crossTrackError

**Units:** m (Meter)

**Description:** The distance from the vessel's present position to the closest point on a line (track) between previousPoint and nextPoint. A negative number indicates that the vessel is currently to the left of this line (and thus must steer right to compensate), a positive number means the vessel is to the right of the line (steer left to compensate).

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/bearingTrackTrue

**Units:** rad (Radian)

**Description:** The bearing of a line between previousPoint and nextPoint, relative to true north.

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/bearingTrackMagnetic

**Units:** rad (Radian)

**Description:** The bearing of a line between previousPoint and nextPoint, relative to magnetic north.

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/activeRoute

**Description:** Data required if sailing to an active route, defined in resources.

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/activeRoute/href

**Description:** A reference (URL) to the presently active route, in resources.

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/activeRoute/estimatedTimeOfArrival

**Description:** The estimated time of arrival at the end of the current route

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/activeRoute/startTime

**Description:** The time this route was activated

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/nextPoint

**Description:** The point on earth the vessel's presently navigating towards

**Fields:**

* position (The position of nextPoint in two dimensions)

  * latitude
  * longitude

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/nextPoint/distance

**Units:** m (Meter)

**Description:** The distance in meters between the vessel's present position and the nextPoint

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/nextPoint/bearingTrue

**Units:** rad (Radian)

**Description:** The bearing of a line between the vessel's current position and nextPoint, relative to true north

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/nextPoint/bearingMagnetic

**Units:** rad (Radian)

**Description:** The bearing of a line between the vessel's current position and nextPoint, relative to magnetic north

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/nextPoint/velocityMadeGood

**Units:** m/s (Meters per second)

**Description:** The velocity component of the vessel towards the nextPoint

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/nextPoint/timeToGo

**Units:** s (Second)

**Description:** Time in seconds to reach nextPoint's perpendicular) with current speed & direction

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/previousPoint

**Description:** The point on earth the vessel's presently navigating from

**Fields:**

* position (The position of lastPoint in two dimensions)

  * latitude
  * longitude

---

#### /vessels/&lt;RegExp&gt;/navigation/courseRhumbline/previousPoint/distance

**Units:** m (Meter)

**Description:** The distance in meters between previousPoint and the vessel's present position

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle

**Title:** Course

**Description:** Course information computed with Great Circle

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/crossTrackError

**Units:** m (Meter)

**Description:** The distance from the vessel's present position to the closest point on a line (track) between previousPoint and nextPoint. A negative number indicates that the vessel is currently to the left of this line (and thus must steer right to compensate), a positive number means the vessel is to the right of the line (steer left to compensate).

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/bearingTrackTrue

**Units:** rad (Radian)

**Description:** The bearing of a line between previousPoint and nextPoint, relative to true north.

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/bearingTrackMagnetic

**Units:** rad (Radian)

**Description:** The bearing of a line between previousPoint and nextPoint, relative to magnetic north.

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/activeRoute

**Description:** Data required if sailing to an active route, defined in resources.

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/activeRoute/href

**Description:** A reference (URL) to the presently active route, in resources.

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/activeRoute/estimatedTimeOfArrival

**Description:** The estimated time of arrival at the end of the current route

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/activeRoute/startTime

**Description:** The time this route was activated

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/nextPoint

**Description:** The point on earth the vessel's presently navigating towards

**Fields:**

* position (The position of nextPoint in two dimensions)

  * latitude
  * longitude

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/nextPoint/distance

**Units:** m (Meter)

**Description:** The distance in meters between the vessel's present position and the nextPoint

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/nextPoint/bearingTrue

**Units:** rad (Radian)

**Description:** The bearing of a line between the vessel's current position and nextPoint, relative to true north

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/nextPoint/bearingMagnetic

**Units:** rad (Radian)

**Description:** The bearing of a line between the vessel's current position and nextPoint, relative to magnetic north

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/nextPoint/velocityMadeGood

**Units:** m/s (Meters per second)

**Description:** The velocity component of the vessel towards the nextPoint

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/nextPoint/timeToGo

**Units:** s (Second)

**Description:** Time in seconds to reach nextPoint's perpendicular) with current speed & direction

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/previousPoint

**Description:** The point on earth the vessel's presently navigating from

**Fields:**

* position (The position of lastPoint in two dimensions)

  * latitude
  * longitude

---

#### /vessels/&lt;RegExp&gt;/navigation/courseGreatCircle/previousPoint/distance

**Units:** m (Meter)

**Description:** The distance in meters between previousPoint and the vessel's present position

---

#### /vessels/&lt;RegExp&gt;/navigation/racing

**Description:** Specific navigational data related to yacht racing.

---

#### /vessels/&lt;RegExp&gt;/navigation/racing/startLineStb

**Description:** Position of starboard start mark

---

#### /vessels/&lt;RegExp&gt;/navigation/racing/startLinePort

**Description:** Position of starboard start mark

---

#### /vessels/&lt;RegExp&gt;/navigation/racing/distanceStartline

**Units:** m (Meter)

**Description:** The current distance to the start line

---

#### /vessels/&lt;RegExp&gt;/navigation/racing/timeToStart

**Units:** s (Second)

**Description:** Time left before start

---

#### /vessels/&lt;RegExp&gt;/navigation/racing/timePortDown

**Units:** s (Second)

**Description:** Time to arrive at the start line on port, turning downwind

---

#### /vessels/&lt;RegExp&gt;/navigation/racing/timePortUp

**Units:** s (Second)

**Description:** Time to arrive at the start line on port, turning upwind

---

#### /vessels/&lt;RegExp&gt;/navigation/racing/timeStbdDown

**Units:** s (Second)

**Description:** Time to arrive at the start line on starboard, turning downwind

---

#### /vessels/&lt;RegExp&gt;/navigation/racing/timeStbdUp

**Units:** s (Second)

**Description:** Time to arrive at the start line on starboard, turning upwind

---

#### /vessels/&lt;RegExp&gt;/navigation/racing/distanceLayline

**Units:** m (Meter)

**Description:** The current distance to the layline

---

#### /vessels/&lt;RegExp&gt;/navigation/magneticVariation

**Units:** rad (Radian)

**Description:** The magnetic variation (declination) at the current position

---

#### /vessels/&lt;RegExp&gt;/navigation/magneticVariationAgeOfService

**Units:** s (Second)

**Description:** Seconds since the 1st Jan 1970 that the variation calculation was made

---

#### /vessels/&lt;RegExp&gt;/navigation/destination

**Title:** destination

**Description:** The intended destination of this trip

**Fields:**

* eta (RFC 3339 (UTC only without local offset) string representing date and time.), units: RFC 3339 (UTC) (undefined)
* waypoint (UUID of destination waypoint)

---

#### /vessels/&lt;RegExp&gt;/navigation/gnss

**Title:** gnss

**Description:** Global satellite navigation meta information

**Fields:**

* methodQuality (Quality of the satellite fix)

  * value, enum:

    * no GPS
    * GNSS Fix
    * DGNSS fix
    * Precise GNSS
    * RTK fixed integer
    * RTK float
    * Estimated (DR) mode
    * Manual input
    * Simulator mode
    * Error

* integrity (Integrity of the satellite fix)

  * value, enum:

    * no Integrity checking
    * Safe
    * Caution
    * Unsafe


---

#### /vessels/&lt;RegExp&gt;/navigation/gnss/satellites

**Description:** Number of satellites

---

#### /vessels/&lt;RegExp&gt;/navigation/gnss/antennaAltitude

**Units:** m (Meter)

**Description:** Altitude of antenna

---

#### /vessels/&lt;RegExp&gt;/navigation/gnss/horizontalDilution

**Description:** Horizontal Dilution of Precision

---

#### /vessels/&lt;RegExp&gt;/navigation/gnss/positionDilution

**Description:** Positional Dilution of Precision

---

#### /vessels/&lt;RegExp&gt;/navigation/gnss/geoidalSeparation

**Description:** Difference between WGS84 earth ellipsoid and mean sea level

---

#### /vessels/&lt;RegExp&gt;/navigation/gnss/differentialAge

**Units:** s (Second)

**Description:** Age of DGPS data

---

#### /vessels/&lt;RegExp&gt;/navigation/gnss/differentialReference

**Description:** ID of DGPS base station

---

#### /vessels/&lt;RegExp&gt;/navigation/headingMagnetic

**Units:** rad (Radian)

**Description:** Current magnetic heading of the vessel

---

#### /vessels/&lt;RegExp&gt;/navigation/headingTrue

**Units:** rad (Radian)

**Description:** The current true heading of the vessel

---

#### /vessels/&lt;RegExp&gt;/navigation/position

**Title:** position

**Description:** The position of the vessel in 2 or 3 dimensions (WGS84 datum)

**Fields:**

* longitude (Longitude), units: deg (Degree)
* latitude (Latitude), units: deg (Degree)
* altitude (Altitude), units: m (Meter)

---

#### /vessels/&lt;RegExp&gt;/navigation/attitude

**Title:** Attitude

**Description:** Vessel attitude: roll, pitch and yaw

**Fields:**

* roll (Vessel roll, +ve is list to starboard), units: rad (Radian)
* pitch (Pitch, +ve is bow up), units: rad (Radian)
* yaw (Yaw, +ve is heading change to starboard), units: rad (Radian)

---

#### /vessels/&lt;RegExp&gt;/navigation/rateOfTurn

**Units:** rad/s (Radian per second)

**Description:** Rate of turn (+ve is change to starboard)

---

#### /vessels/&lt;RegExp&gt;/navigation/speedOverGround

**Units:** m/s (Meters per second)

**Description:** Vessel speed over ground

---

#### /vessels/&lt;RegExp&gt;/navigation/speedThroughWater

**Units:** m/s (Meters per second)

**Description:** Vessel speed through the water

---

#### /vessels/&lt;RegExp&gt;/navigation/speedThroughWaterTransverse

**Units:** m/s (Meters per second)

**Description:** Transverse speed through the water (Leeway)

---

#### /vessels/&lt;RegExp&gt;/navigation/speedThroughWaterLongitudinal

**Units:** m/s (Meters per second)

**Description:** Longitudinal speed through the water

---

#### /vessels/&lt;RegExp&gt;/navigation/leewayAngle

**Units:** rad (Radian)

**Description:** Leeway Angle derived from the longitudinal and transverse speeds through the water

---

#### /vessels/&lt;RegExp&gt;/navigation/log

**Units:** m (Meter)

**Description:** Log value

---

#### /vessels/&lt;RegExp&gt;/navigation/trip

**Description:** Trip data

---

#### /vessels/&lt;RegExp&gt;/navigation/trip/log

**Units:** m (Meter)

**Description:** Trip log value

---

#### /vessels/&lt;RegExp&gt;/navigation/trip/lastReset

**Description:** Trip log reset time

---

#### /vessels/&lt;RegExp&gt;/navigation/state

**Title:** state

**Description:** Current navigational state of the vessel

---

#### /vessels/&lt;RegExp&gt;/navigation/anchor

**Title:** anchor

**Description:** The anchor data, for anchor watch etc

---

#### /vessels/&lt;RegExp&gt;/navigation/anchor/maxRadius

**Units:** m (Meter)

**Description:** Radius of anchor alarm boundary. The distance from anchor to the center of the boat

---

#### /vessels/&lt;RegExp&gt;/navigation/anchor/currentRadius

**Units:** m (Meter)

**Description:** Current distance to anchor

---

#### /vessels/&lt;RegExp&gt;/navigation/anchor/position

**Title:** position

**Description:** The actual anchor position of the vessel in 3 dimensions, probably an estimate at best

**Fields:**

* longitude (Longitude), units: deg (Degree)
* latitude (Latitude), units: deg (Degree)
* altitude (Altitude), units: m (Meter)

---

#### /vessels/&lt;RegExp&gt;/navigation/datetime

**Description:** Time and Date from the GNSS Positioning System

**Fields:**

* gnssTimeSource (Source of GNSS Date and Time), enum:

  * GPS
  * GLONASS
  * Galileo
  * Beidou
  * IRNSS
  * Radio Signal
  * Internet
  * Local clock


---

#### /vessels/&lt;RegExp&gt;/propulsion

**Title:** propulsion

**Description:** Engine data, each engine identified by a unique name i.e. Port_Engine

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;

**Description:** This regex pattern is used for validation of the identifier for the propulsion unit

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/label

**Description:** Human readable label for the propulsion unit

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/state

**Description:** The current state of the engine

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/revolutions

**Units:** Hz (Hertz)

**Description:** Engine revolutions (x60 for RPM)

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/temperature

**Units:** K (Kelvin)

**Description:** Engine temperature

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/oilTemperature

**Units:** K (Kelvin)

**Description:** Oil temperature

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/oilPressure

**Units:** Pa (Pascal)

**Description:** Oil pressure

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/alternatorVoltage

**Units:** V (Volt)

**Description:** Alternator voltage

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/runTime

**Units:** s (Second)

**Description:** Total running time for engine (Engine Hours in seconds)

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/coolantTemperature

**Units:** K (Kelvin)

**Description:** Coolant temperature

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/coolantPressure

**Units:** Pa (Pascal)

**Description:** Coolant pressure

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/boostPressure

**Units:** Pa (Pascal)

**Description:** Engine boost (turbo, supercharger) pressure

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/engineLoad

**Units:** ratio (Ratio)

**Description:** Engine load ratio, 0<=ratio<=1, 1 is 100%

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/engineTorque

**Units:** ratio (Ratio)

**Description:** Engine torque ratio, 0<=ratio<=1, 1 is 100%

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/transmission

**Description:** The transmission (gear box) of the named engine

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/transmission/gear

**Description:** Currently selected gear the engine is in i.e. Forward, Reverse, etc.

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/transmission/gearRatio

**Units:** ratio (Ratio)

**Description:** Gear ratio, engine rotations per propeller shaft rotation

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/transmission/oilTemperature

**Units:** K (Kelvin)

**Description:** Oil temperature

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/transmission/oilPressure

**Units:** Pa (Pascal)

**Description:** Oil pressure

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/drive

**Description:** Data about the engine's drive.

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/drive/type

**Description:** The type of drive the boat has i.e Outboard, shaft, jet, etc.

**Enum values:**

* saildrive
* shaft
* outboard
* jet
* pod
* other

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/drive/trimState

**Units:** ratio (Ratio)

**Description:** Trim/tilt state, 0<=ratio<=1, 1 is 100% up

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/drive/thrustAngle

**Units:** rad (Radian)

**Description:** Current thrust angle for steerable drives, +ve is thrust to Starboard

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/drive/propeller

**Description:** Data about the drive's propeller (pitch and slip)

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/fuel

**Description:** Data about the engine's Fuel Supply

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/fuel/type

**Description:** Fuel type

**Enum values:**

* diesel
* petrol
* electric
* coal/wood
* other

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/fuel/used

**Units:** m3 (Cubic meter)

**Description:** Used fuel since last reset. Resetting is at user discretion

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/fuel/pressure

**Units:** Pa (Pascal)

**Description:** Fuel pressure

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/fuel/rate

**Units:** m3/s (Cubic meter per second)

**Description:** Fuel rate  of consumption

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/fuel/economyRate

**Units:** m3/s (Cubic meter per second)

**Description:** Economy fuel rate of consumption

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/fuel/averageRate

**Units:** m3/s (Cubic meter per second)

**Description:** Average fuel rate of consumption

---

#### /vessels/&lt;RegExp&gt;/propulsion/&lt;RegExp&gt;/exhaustTemperature

**Units:** K (Kelvin)

**Description:** Exhaust temperature

---

#### /vessels/&lt;RegExp&gt;/electrical

**Title:** electrical

**Description:** Electrical data, each electrical device indentified by a unique name i.e. Battery_1

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries

**Description:** Data about the vessel's batteries

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;

**Title:** Battery keyed by instance id

**Description:** Batteries, one or many, within the vessel

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/temperature

**Title:** temperature

**Description:** Additional / unique temperatures associated with a battery

**Fields:**

* limitDischargeLower (Operational minimum temperature limit for battery discharge), units: K (Kelvin)
* limitDischargeUpper (Operational maximum temperature limit for battery discharge), units: K (Kelvin)
* limitRechargeLower (Operational minimum temperature limit for battery recharging), units: K (Kelvin)
* limitRechargeUpper (Operational maximum temperature limit for battery recharging), units: K (Kelvin)
* warnUpper (Upper operational temperature limit), units: K (Kelvin)
* warnLower (Lower operational temperature limit), units: K (Kelvin)
* faultUpper (Upper fault temperature limit - device may disable/disconnect), units: K (Kelvin)
* faultLower (Lower fault temperature limit - device may disable/disconnect), units: K (Kelvin)

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/capacity

**Title:** capacity

**Description:** Data about the battery's capacity

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/capacity/nominal

**Units:** J (Joule)

**Description:** The capacity of battery as specified by the manufacturer

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/capacity/actual

**Units:** J (Joule)

**Description:** The measured capacity of battery. This may change over time and will likely deviate from the nominal capacity.

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/capacity/remaining

**Units:** J (Joule)

**Description:** Capacity remaining in battery

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/capacity/dischargeLimit

**Units:** J (Joule)

**Description:** Minimum capacity to be left in the battery while discharging

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/capacity/stateOfCharge

**Units:** ratio (Ratio)

**Description:** State of charge, 1 = 100%

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/capacity/stateOfHealth

**Units:** ratio (Ratio)

**Description:** State of Health, 1 = 100%

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/capacity/dischargeSinceFull

**Units:** C (Coulomb)

**Description:** Cumulative discharge since battery was last full

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/capacity/timeRemaining

**Units:** s (Second)

**Description:** Time to discharge to discharge limit at current rate

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/lifetimeDischarge

**Units:** C (Coulomb)

**Description:** Cumulative charge discharged from battery over operational lifetime of battery

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/lifetimeRecharge

**Units:** C (Coulomb)

**Description:** Cumulative charge recharged into battery over operational lifetime of battery

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/associatedBus

**Description:** Name of BUS device is associated with

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/voltage

**Units:** V (Volt)

**Description:** Voltage measured as close as possible to the device

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/voltage/ripple

**Units:** V (Volt)

**Description:** DC Ripple voltage

---

#### /vessels/&lt;RegExp&gt;/electrical/batteries/&lt;RegExp&gt;/current

**Units:** A (Ampere)

**Description:** Current flowing out (+ve) or in (-ve) to the device

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters

**Description:** Data about the Inverter that has both DC and AC quantities

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;

**Title:** Inverter

**Description:** DC to AC inverter, one or many, within the vessel

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/dc

**Title:** DC Quantities

**Description:** DC common quantities

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/dc/associatedBus

**Description:** Name of BUS device is associated with

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/dc/voltage

**Units:** V (Volt)

**Description:** Voltage measured as close as possible to the device

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/dc/voltage/ripple

**Units:** V (Volt)

**Description:** DC Ripple voltage

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/dc/current

**Units:** A (Ampere)

**Description:** Current flowing out (+ve) or in (-ve) to the device

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/dc/temperature

**Title:** temperature

**Description:** Temperature measured within or on the device

**Fields:**

* warnUpper (Upper operational temperature limit), units: K (Kelvin)
* warnLower (Lower operational temperature limit), units: K (Kelvin)
* faultUpper (Upper fault temperature limit - device may disable/disconnect), units: K (Kelvin)
* faultLower (Lower fault temperature limit - device may disable/disconnect), units: K (Kelvin)

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac

**Title:** AC Quantities

**Description:** AC equipment common quantities

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/associatedBus

**Description:** Name of BUS source is assocated with (if applicable, may = NULL)

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/lineNeutralVoltage

**Units:** V (Volt)

**Description:** RMS voltage measured between phase and neutral.

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/lineLineVoltage

**Units:** V (Volt)

**Description:** RMS voltage measured between phases

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/current

**Units:** A (Ampere)

**Description:** RMS current

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/frequency

**Units:** Hz (Hertz)

**Description:** AC frequency.

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/reactivePower

**Units:** W (Watt)

**Description:** Reactive power

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/powerFactor

**Description:** Power factor

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/powerFactorLagging

**Description:** Lead/lag status.

**Enum values:**

* leading
* lagging
* error
* not available

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/realPower

**Units:** W (Watt)

**Description:** Real power.

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/ac/apparentPower

**Units:** W (Watt)

**Description:** Apparent power.

---

#### /vessels/&lt;RegExp&gt;/electrical/inverters/&lt;RegExp&gt;/mode

**Description:** Mode of inverter

---

#### /vessels/&lt;RegExp&gt;/electrical/chargers

**Description:** Data about the Charger that has both DC and AC quantities

---

#### /vessels/&lt;RegExp&gt;/electrical/chargers/&lt;RegExp&gt;

**Title:** Charger

**Description:** Battery charger

---

#### /vessels/&lt;RegExp&gt;/electrical/chargers/&lt;RegExp&gt;/associatedBus

**Description:** Name of BUS device is associated with

---

#### /vessels/&lt;RegExp&gt;/electrical/chargers/&lt;RegExp&gt;/voltage

**Units:** V (Volt)

**Description:** Voltage measured as close as possible to the device

---

#### /vessels/&lt;RegExp&gt;/electrical/chargers/&lt;RegExp&gt;/voltage/ripple

**Units:** V (Volt)

**Description:** DC Ripple voltage

---

#### /vessels/&lt;RegExp&gt;/electrical/chargers/&lt;RegExp&gt;/current

**Units:** A (Ampere)

**Description:** Current flowing out (+ve) or in (-ve) to the device

---

#### /vessels/&lt;RegExp&gt;/electrical/chargers/&lt;RegExp&gt;/temperature

**Title:** temperature

**Description:** Temperature measured within or on the device

**Fields:**

* warnUpper (Upper operational temperature limit), units: K (Kelvin)
* warnLower (Lower operational temperature limit), units: K (Kelvin)
* faultUpper (Upper fault temperature limit - device may disable/disconnect), units: K (Kelvin)
* faultLower (Lower fault temperature limit - device may disable/disconnect), units: K (Kelvin)

---

#### /vessels/&lt;RegExp&gt;/electrical/chargers/&lt;RegExp&gt;/mode

**Description:** Charging mode i.e. float, overcharge, etc.

---

#### /vessels/&lt;RegExp&gt;/electrical/ac

**Description:** AC buses

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;

**Title:** AC Bus keyed by instance id

**Description:** AC Bus, one or many, within the vessel

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase

**Description:** Single or A,B or C in 3 Phase systems 

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])

**Title:** AC Quantities

**Description:** AC equipment common quantities

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/associatedBus

**Description:** Name of BUS source is assocated with (if applicable, may = NULL)

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/lineNeutralVoltage

**Units:** V (Volt)

**Description:** RMS voltage measured between phase and neutral.

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/lineLineVoltage

**Units:** V (Volt)

**Description:** RMS voltage measured between phases

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/current

**Units:** A (Ampere)

**Description:** RMS current

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/frequency

**Units:** Hz (Hertz)

**Description:** AC frequency.

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/reactivePower

**Units:** W (Watt)

**Description:** Reactive power

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/powerFactor

**Description:** Power factor

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/powerFactorLagging

**Description:** Lead/lag status.

**Enum values:**

* leading
* lagging
* error
* not available

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/realPower

**Units:** W (Watt)

**Description:** Real power.

---

#### /vessels/&lt;RegExp&gt;/electrical/ac/&lt;RegExp&gt;/phase/(single)|([A-C])/apparentPower

**Units:** W (Watt)

**Description:** Apparent power.

---

#### /vessels/&lt;RegExp&gt;/notifications

**Title:** notifications

**Description:** Notifications currently raised. Major categories have well-defined names, but the tree can be extended by any hierarchical structure

---

#### /vessels/&lt;RegExp&gt;/notifications/mob

**Description:** Man overboard

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/fire

**Description:** Fire onboard

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/sinking

**Description:** Vessel is sinking

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/flooding

**Description:** Vessel is flooding

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/collision

**Description:** In collision with another vessel or object

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/grounding

**Description:** Vessel grounding

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/listing

**Description:** Vessel is listing

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/adrift

**Description:** Vessel is adrift

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/piracy

**Description:** Under attack or danger from pirates

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/abandon

**Description:** Abandon ship

**Fields:**

* method (Method to use to raise notifications)
* state (Current notification state), enum:

  * normal
  * alert
  * warn
  * alarm
  * emergency

* message (Message to display or speak)

---

#### /vessels/&lt;RegExp&gt;/notifications/&lt;RegExp&gt;

**Description:** This regex pattern is used for validation of the path of the alarm

---

#### /vessels/&lt;RegExp&gt;/steering

**Title:** steering

**Description:** Vessel steering data for steering controls (not Autopilot 'Nav Data')

---

#### /vessels/&lt;RegExp&gt;/steering/rudderAngle

**Units:** rad (Radian)

**Description:** Current rudder angle, +ve is rudder to Starboard

---

#### /vessels/&lt;RegExp&gt;/steering/rudderAngleTarget

**Units:** rad (Radian)

**Description:** The angle the rudder should move to, +ve is rudder to Starboard

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot

**Title:** autopilot

**Description:** Autopilot data

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/state

**Description:** Autopilot state

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/mode

**Description:** Operational mode

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/target

**Title:** target

**Description:** Autopilot target

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/target/windAngleApparent

**Units:** rad (Radian)

**Description:** Target angle to steer, relative to Apparent wind +port -starboard

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/target/headingTrue

**Units:** rad (Radian)

**Description:** Target heading for autopilot, relative to North

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/target/headingMagnetic

**Units:** rad (Radian)

**Description:** Target heading for autopilot, relative to Magnetic North

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/deadZone

**Units:** rad (Radian)

**Description:** Dead zone to ignore for rudder corrections

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/backlash

**Units:** rad (Radian)

**Description:** Slack in the rudder drive mechanism

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/gain

**Description:** Auto-pilot gain, higher number equals more rudder movement for a given turn

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/maxDriveCurrent

**Units:** A (Ampere)

**Description:** Maximum current to use to drive servo

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/maxDriveRate

**Units:** rad/s (Radian per second)

**Description:** Maximum rudder rotation speed

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/portLock

**Units:** rad (Radian)

**Description:** Position of servo on port lock

---

#### /vessels/&lt;RegExp&gt;/steering/autopilot/starboardLock

**Units:** rad (Radian)

**Description:** Position of servo on starboard lock

---

#### /vessels/&lt;RegExp&gt;/tanks

**Title:** tanks

**Description:** Tank data, each tank indentified by a unique name i.e. FreshWater_2

---

#### /vessels/&lt;RegExp&gt;/tanks/freshWater

**Description:** Fresh water tank (drinking)

---

#### /vessels/&lt;RegExp&gt;/tanks/freshWater/&lt;RegExp&gt;

**Description:** Tank, one or many, within the vessel

---

#### /vessels/&lt;RegExp&gt;/tanks/freshWater/&lt;RegExp&gt;/name

**Description:** The name of the tank. Useful if multiple tanks of a certain type are on board

---

#### /vessels/&lt;RegExp&gt;/tanks/freshWater/&lt;RegExp&gt;/type

**Description:** The type of tank

**Enum values:**

* petrol
* fresh water
* greywater
* holding
* lpg
* diesel
* rum

---

#### /vessels/&lt;RegExp&gt;/tanks/freshWater/&lt;RegExp&gt;/capacity

**Units:** m3 (Cubic meter)

**Description:** Total capacity

---

#### /vessels/&lt;RegExp&gt;/tanks/freshWater/&lt;RegExp&gt;/currentLevel

**Units:** ratio (Ratio)

**Description:** Level of fluid in tank 0-100%

---

#### /vessels/&lt;RegExp&gt;/tanks/freshWater/&lt;RegExp&gt;/currentVolume

**Units:** m3 (Cubic meter)

**Description:** Volume of fluid in tank

---

#### /vessels/&lt;RegExp&gt;/tanks/wasteWater

**Description:** Waste water tank (grey water)

---

#### /vessels/&lt;RegExp&gt;/tanks/wasteWater/&lt;RegExp&gt;

**Description:** Tank, one or many, within the vessel

---

#### /vessels/&lt;RegExp&gt;/tanks/wasteWater/&lt;RegExp&gt;/name

**Description:** The name of the tank. Useful if multiple tanks of a certain type are on board

---

#### /vessels/&lt;RegExp&gt;/tanks/wasteWater/&lt;RegExp&gt;/type

**Description:** The type of tank

**Enum values:**

* petrol
* fresh water
* greywater
* holding
* lpg
* diesel
* rum

---

#### /vessels/&lt;RegExp&gt;/tanks/wasteWater/&lt;RegExp&gt;/capacity

**Units:** m3 (Cubic meter)

**Description:** Total capacity

---

#### /vessels/&lt;RegExp&gt;/tanks/wasteWater/&lt;RegExp&gt;/currentLevel

**Units:** ratio (Ratio)

**Description:** Level of fluid in tank 0-100%

---

#### /vessels/&lt;RegExp&gt;/tanks/wasteWater/&lt;RegExp&gt;/currentVolume

**Units:** m3 (Cubic meter)

**Description:** Volume of fluid in tank

---

#### /vessels/&lt;RegExp&gt;/tanks/blackWater

**Description:** Black water tank (sewage)

---

#### /vessels/&lt;RegExp&gt;/tanks/blackWater/&lt;RegExp&gt;

**Description:** Tank, one or many, within the vessel

---

#### /vessels/&lt;RegExp&gt;/tanks/blackWater/&lt;RegExp&gt;/name

**Description:** The name of the tank. Useful if multiple tanks of a certain type are on board

---

#### /vessels/&lt;RegExp&gt;/tanks/blackWater/&lt;RegExp&gt;/type

**Description:** The type of tank

**Enum values:**

* petrol
* fresh water
* greywater
* holding
* lpg
* diesel
* rum

---

#### /vessels/&lt;RegExp&gt;/tanks/blackWater/&lt;RegExp&gt;/capacity

**Units:** m3 (Cubic meter)

**Description:** Total capacity

---

#### /vessels/&lt;RegExp&gt;/tanks/blackWater/&lt;RegExp&gt;/currentLevel

**Units:** ratio (Ratio)

**Description:** Level of fluid in tank 0-100%

---

#### /vessels/&lt;RegExp&gt;/tanks/blackWater/&lt;RegExp&gt;/currentVolume

**Units:** m3 (Cubic meter)

**Description:** Volume of fluid in tank

---

#### /vessels/&lt;RegExp&gt;/tanks/fuel

**Description:** Fuel tank (petrol or diesel)

---

#### /vessels/&lt;RegExp&gt;/tanks/fuel/&lt;RegExp&gt;

**Description:** Tank, one or many, within the vessel

---

#### /vessels/&lt;RegExp&gt;/tanks/fuel/&lt;RegExp&gt;/name

**Description:** The name of the tank. Useful if multiple tanks of a certain type are on board

---

#### /vessels/&lt;RegExp&gt;/tanks/fuel/&lt;RegExp&gt;/type

**Description:** The type of tank

**Enum values:**

* petrol
* fresh water
* greywater
* holding
* lpg
* diesel
* rum

---

#### /vessels/&lt;RegExp&gt;/tanks/fuel/&lt;RegExp&gt;/capacity

**Units:** m3 (Cubic meter)

**Description:** Total capacity

---

#### /vessels/&lt;RegExp&gt;/tanks/fuel/&lt;RegExp&gt;/currentLevel

**Units:** ratio (Ratio)

**Description:** Level of fluid in tank 0-100%

---

#### /vessels/&lt;RegExp&gt;/tanks/fuel/&lt;RegExp&gt;/currentVolume

**Units:** m3 (Cubic meter)

**Description:** Volume of fluid in tank

---

#### /vessels/&lt;RegExp&gt;/tanks/lubrication

**Description:** Lubrication tank (oil or grease)

---

#### /vessels/&lt;RegExp&gt;/tanks/lubrication/&lt;RegExp&gt;

**Description:** Tank, one or many, within the vessel

---

#### /vessels/&lt;RegExp&gt;/tanks/lubrication/&lt;RegExp&gt;/name

**Description:** The name of the tank. Useful if multiple tanks of a certain type are on board

---

#### /vessels/&lt;RegExp&gt;/tanks/lubrication/&lt;RegExp&gt;/type

**Description:** The type of tank

**Enum values:**

* petrol
* fresh water
* greywater
* holding
* lpg
* diesel
* rum

---

#### /vessels/&lt;RegExp&gt;/tanks/lubrication/&lt;RegExp&gt;/capacity

**Units:** m3 (Cubic meter)

**Description:** Total capacity

---

#### /vessels/&lt;RegExp&gt;/tanks/lubrication/&lt;RegExp&gt;/currentLevel

**Units:** ratio (Ratio)

**Description:** Level of fluid in tank 0-100%

---

#### /vessels/&lt;RegExp&gt;/tanks/lubrication/&lt;RegExp&gt;/currentVolume

**Units:** m3 (Cubic meter)

**Description:** Volume of fluid in tank

---

#### /vessels/&lt;RegExp&gt;/tanks/liveWell

**Description:** Live tank (fish)

---

#### /vessels/&lt;RegExp&gt;/tanks/liveWell/&lt;RegExp&gt;

**Description:** Tank, one or many, within the vessel

---

#### /vessels/&lt;RegExp&gt;/tanks/liveWell/&lt;RegExp&gt;/name

**Description:** The name of the tank. Useful if multiple tanks of a certain type are on board

---

#### /vessels/&lt;RegExp&gt;/tanks/liveWell/&lt;RegExp&gt;/type

**Description:** The type of tank

**Enum values:**

* petrol
* fresh water
* greywater
* holding
* lpg
* diesel
* rum

---

#### /vessels/&lt;RegExp&gt;/tanks/liveWell/&lt;RegExp&gt;/capacity

**Units:** m3 (Cubic meter)

**Description:** Total capacity

---

#### /vessels/&lt;RegExp&gt;/tanks/liveWell/&lt;RegExp&gt;/currentLevel

**Units:** ratio (Ratio)

**Description:** Level of fluid in tank 0-100%

---

#### /vessels/&lt;RegExp&gt;/tanks/liveWell/&lt;RegExp&gt;/currentVolume

**Units:** m3 (Cubic meter)

**Description:** Volume of fluid in tank

---

#### /vessels/&lt;RegExp&gt;/design

**Title:** design

**Description:** Design/dimensional data of this vessel

---

#### /vessels/&lt;RegExp&gt;/design/displacement

**Units:** kg (Kilogram)

**Description:** The displacement of the vessel

---

#### /vessels/&lt;RegExp&gt;/design/draft

**Title:** draft

**Description:** The draft of the vessel

**Fields:**

* minimum (The minimum draft of the vessel), units: m (Meter)
* maximum (The maximum draft of the vessel), units: m (Meter)
* canoe (The draft of the vessel without protrusions such as keel, centerboard, rudder), units: m (Meter)

---

#### /vessels/&lt;RegExp&gt;/design/length

**Title:** length

**Description:** The various lengths of the vessel

**Fields:**

* overall (Length overall), units: m (Meter)
* hull (Length of hull), units: m (Meter)
* waterline (Length at waterline), units: m (Meter)

---

#### /vessels/&lt;RegExp&gt;/design/keel

**Title:** keel

**Description:** Information about the vessel's keel

**Fields:**

* type (The type of keel.), enum:

  * long
  * fin
  * flare
  * bulb
  * wing
  * centerboard
  * kanting
  * lifting
  * daggerboard


---

#### /vessels/&lt;RegExp&gt;/design/keel/angle

**Units:** rad (Radian)

**Description:** A number indicating at which angle the keel currently is (in case of a canting keel), negative to port.

---

#### /vessels/&lt;RegExp&gt;/design/keel/lift

**Units:** ratio (Ratio)

**Description:** In the case of a lifting keel, centreboard or daggerboard, the part of the keel which is extended. 0 is 'all the way up' and 1 is 'all the way down'. 0.8 would be 80% down.

---

#### /vessels/&lt;RegExp&gt;/design/beam

**Units:** m (Meter)

**Description:** Beam length

---

#### /vessels/&lt;RegExp&gt;/design/airHeight

**Units:** m (Meter)

**Description:** Total height of the vessel

---

#### /vessels/&lt;RegExp&gt;/design/rigging

**Title:** rigging

**Description:** Information about the vessel's rigging

**Fields:**

* configuration (The configuration of the rigging)
* masts (The number of masts on the vessel.)

---

#### /vessels/&lt;RegExp&gt;/sails

**Title:** sails

**Description:** Sails data

---

#### /vessels/&lt;RegExp&gt;/sails/inventory

**Description:** An object containing a description of each sail available to the vessel crew

---

#### /vessels/&lt;RegExp&gt;/sails/inventory/&lt;RegExp&gt;

**Description:** 'sail' data type.

**Fields:**

* name (An unique identifier by which the crew identifies a sail)
* type (The type of sail)
* material (The material the sail is made from (optional))
* brand (The brand of the sail (optional))
* active (Indicates wether this sail is currently in use or not)
* area (The total area of this sail in square meters), units: m2 (Square meter)
* minimumWind (The minimum wind speed this sail can be used with), units: m/s (Meters per second)
* maximumWind (The maximum wind speed this sail can be used with), units: m/s (Meters per second)

---

#### /vessels/&lt;RegExp&gt;/sails/area

**Description:** An object containing information about the vessels' sails.

---

#### /vessels/&lt;RegExp&gt;/sails/area/total

**Units:** m2 (Square meter)

**Description:** The total area of all sails on the vessel

---

#### /vessels/&lt;RegExp&gt;/sails/area/active

**Units:** m2 (Square meter)

**Description:** The total area of the sails currently in use on the vessel

---

#### /vessels/&lt;RegExp&gt;/sensors

**Title:** sensors

**Description:** Sensors, their state, and data.

---

#### /vessels/&lt;RegExp&gt;/sensors/&lt;RegExp&gt;

**Title:** sensor

**Description:** This regex pattern is used for validation UUID identifier for the sensor

---

#### /vessels/&lt;RegExp&gt;/sensors/&lt;RegExp&gt;/name

**Description:** The common name of the sensor

---

#### /vessels/&lt;RegExp&gt;/sensors/&lt;RegExp&gt;/sensorType

**Description:** The datamodel definition of the sensor data. FIXME - need to create a definitions lib of sensor datamodel types

---

#### /vessels/&lt;RegExp&gt;/sensors/&lt;RegExp&gt;/sensorData

**Description:** The data of the sensor data. FIXME - need to ref the definitions of sensor types

---

#### /vessels/&lt;RegExp&gt;/sensors/&lt;RegExp&gt;/fromBow

**Description:** The distance from the bow to the sensor location

---

#### /vessels/&lt;RegExp&gt;/sensors/&lt;RegExp&gt;/fromCenter

**Description:** The distance from the centerline to the sensor location, -ve to starboard, +ve to port

---

#### /vessels/&lt;RegExp&gt;/performance

**Title:** performance

**Description:** Performance Sailing data including VMG, Polar Speed, tack angle, etc.

---

#### /vessels/&lt;RegExp&gt;/performance/polarSpeed

**Units:** m/s (Meters per second)

**Description:** The current polar speed based on current polar diagram, trueWindSpeed and truewindAngle.

---

#### /vessels/&lt;RegExp&gt;/performance/polarSpeedRatio

**Units:** ratio (Ratio)

**Description:** The ratio of current speed through water to the polar speed.

---

#### /vessels/&lt;RegExp&gt;/performance/velocityMadeGood

**Units:** m/s (Meters per second)

**Description:** The current velocity made good derived from the speed through water and appearant wind angle. A positive value is heading to upwind, negative to downwind.

---

#### /vessels/&lt;RegExp&gt;/performance/velocityMadeGoodToWaypoint

**Units:** m/s (Meters per second)

**Description:** The current velocity made good to the next waypoint derived from the speedOverGround, courseOverGround.

---

#### /vessels/&lt;RegExp&gt;/performance/beatAngle

**Units:** rad (Radian)

**Description:** The true wind beat angle for the best velocity made good based on current current polar diagram and trueWindSpeed.

---

#### /vessels/&lt;RegExp&gt;/performance/beatAngleVelocityMadeGood

**Units:** m/s (Meters per second)

**Description:** The velocity made good for the beat angle.

---

#### /vessels/&lt;RegExp&gt;/performance/beatAngleTargetSpeed

**Units:** m/s (Meters per second)

**Description:** The target speed for the beat angle.

---

#### /vessels/&lt;RegExp&gt;/performance/gybeAngle

**Units:** rad (Radian)

**Description:** The true wind gybe angle for the best velocity made good downwind based on current polar diagram and trueWindSpeed.

---

#### /vessels/&lt;RegExp&gt;/performance/gybeAngleVelocityMadeGood

**Units:** m/s (Meters per second)

**Description:** The velocity made good for the gybe angle

---

#### /vessels/&lt;RegExp&gt;/performance/gybeAngleTargetSpeed

**Units:** m/s (Meters per second)

**Description:** The target speed for the gybe angle.

---

#### /vessels/&lt;RegExp&gt;/performance/targetAngle

**Units:** rad (Radian)

**Description:** The true wind gybe or beat angle for the best velocity made good downwind or upwind based on current polar diagram and trueWindSpeed.

---

#### /vessels/&lt;RegExp&gt;/performance/targetSpeed

**Units:** m/s (Meters per second)

**Description:** The target speed for the beat angle or gybe angle, which ever is applicable.

---

#### /vessels/&lt;RegExp&gt;/performance/leeway

**Units:** rad (Radian)

**Description:** Current leeway

---

#### /vessels/&lt;RegExp&gt;/performance/tackMagnetic

**Units:** rad (Radian)

**Description:** Magnetic heading on opposite tack.

---

#### /vessels/&lt;RegExp&gt;/performance/tackTrue

**Units:** rad (Radian)

**Description:** True heading on opposite tack.

---

#### /resources

**Title:** resources

**Description:** Resources to aid in navigation and operation of the vessel including waypoints, routes, notes, etc.

---

#### /resources/charts

**Title:** chart

**Description:** A holder for charts, each named with their chart code

---

#### /resources/charts/&lt;RegExp&gt;

**Description:** A chart

**Fields:**

* name (Chart common name)
* identifier (Chart number)
* description (A description of the chart)
* tilemapUrl (A url to the tilemap of the chart for use in TMS chartplotting apps)
* region (Region related to note. A pointer to a region UUID. Alternative to geohash)
* geohash (Position related to chart. Alternative to region)
* chartUrl (A url to the chart file's storage location)
* scale (The scale of the chart, the larger number from 1:200000)
* chartLayers (If the chart format is WMS, the layers enabled for the chart.)
* bounds (The bounds of the chart. An array containing the position of the upper left corner, and the lower right corner. Useful when the chart isn't inherently geo-referenced.)
* chartFormat (The format of the chart), enum:

  * gif
  * geotiff
  * kap
  * png
  * jpg
  * kml
  * wkt
  * topojson
  * geojson
  * gpx
  * tms
  * wms
  * S-57
  * S-63
  * svg
  * other


---

#### /resources/routes

**Title:** route

**Description:** A holder for routes, each named with a UUID

---

#### /resources/routes/&lt;RegExp&gt;

**Description:** A route, named with a UUID

**Fields:**

* name (Route's common name)
* description (A description of the route)
* distance (Total distance from start to end), units: m (Meter)
* start (The waypoint UUID at the start of the route)
* end (The waypoint UUID at the end of the route)
* feature (A Geo JSON feature object which describes the route between the waypoints)

  * type, enum:

    * Feature

  * geometry

    * type, enum:

      * LineString

    * coordinates (An array of two or more positions)
  * properties (Additional data of any type)
  * id

---

#### /resources/notes

**Title:** notes

**Description:** A holder for notes about regions, each named with a UUID. Notes might include navigation or cruising info, images, or anything

---

#### /resources/notes/&lt;RegExp&gt;

**Description:** A note about a region, named with a UUID. Notes might include navigation or cruising info, images, or anything

**Fields:**

* title (Note's common name)
* description (A textual description of the note)
* region (Region related to note. A pointer to a region UUID. Alternative to position or geohash)
* geohash (Position related to note. Alternative to region or position)
* mimeType (MIME type of the note)
* url (Location of the note)

---

#### /resources/notes/&lt;RegExp&gt;/position

**Title:** position

**Description:** Position related to note. Alternative to region or geohash

**Fields:**

* longitude (Longitude), units: deg (Degree)
* latitude (Latitude), units: deg (Degree)
* altitude (Altitude), units: m (Meter)

---

#### /resources/regions

**Title:** region

**Description:** A holder for regions, each named with UUID

---

#### /resources/regions/&lt;RegExp&gt;

**Description:** A region of interest, each named with a UUID

**Fields:**

* geohash (geohash of the approximate boundary of this region)
* feature (A Geo JSON feature object which describes the regions boundary)

  * type, enum:

    * Feature

  * geometry
  * properties (Additional data of any type)
  * id

---

#### /resources/waypoints

**Title:** waypoints

**Description:** A holder for waypoints, each named with a UUID

---

#### /resources/waypoints/&lt;RegExp&gt;

**Description:** A waypoint, named with a UUID

---

#### /resources/waypoints/&lt;RegExp&gt;/position

**Title:** position

**Description:** The position in 3 dimensions

**Fields:**

* longitude (Longitude), units: deg (Degree)
* latitude (Latitude), units: deg (Degree)
* altitude (Altitude), units: m (Meter)

---

#### /resources/waypoints/&lt;RegExp&gt;/feature

**Title:** Feature

**Description:** A Geo JSON feature object

---

#### /resources/waypoints/&lt;RegExp&gt;/feature/type

**Description:** [missing]

**Enum values:**

* Feature

---

#### /resources/waypoints/&lt;RegExp&gt;/feature/geometry

**Title:** Point

**Description:** [missing]

---

#### /resources/waypoints/&lt;RegExp&gt;/feature/geometry/type

**Description:** [missing]

**Enum values:**

* Point

---

#### /resources/waypoints/&lt;RegExp&gt;/feature/geometry/coordinates

**Description:** A single position, in x,y order (Lon, Lat)

---

#### /resources/waypoints/&lt;RegExp&gt;/feature/properties

**Description:** Additional data of any type

---

#### /resources/waypoints/&lt;RegExp&gt;/feature/id

**Description:** [missing]

---

#### /version

**Description:** Version of the schema and APIs that this data is using in Canonical format i.e. V1.0.0.

---

